
#' reproduction
#' 
#' @return a table of species reproduction
#' @inheritParams species
#' @export
#' @examples \dontrun{
#' reproduction("Oreochromis niloticus")
#' }
reproduction <- endpoint("reproduc")


#' fecundity
#' 
#' @return a table of species fecundity
#' @inheritParams species
#' @export
#' @examples \dontrun{
#' fecundity("Oreochromis niloticus")
#' }
fecundity <- endpoint("fecundity")


#' maturity
#' 
#' @return a table of species maturity
#' @inheritParams species
#' @export
#' @examples \dontrun{
#' maturity("Oreochromis niloticus")
#' }
maturity <- endpoint("maturity")


#' spawning
#' 
#' @return a table of species spawning
#' @inheritParams species
#' @export
#' @examples \dontrun{
#' spawning("Oreochromis niloticus")
#' }
spawning <- endpoint("spawning")

#' larvae
#' 
#' @return a table of larval data
#' @inheritParams species
#' @export
#' @examples \dontrun{
#' larvae("Oreochromis niloticus")
#' }
larvae <- endpoint("larvae")
